@@ -22,7 +22,7 @@
 #       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-VERSION=4.0.15
+VERSION=4.2.10
 
 usage() # $1 = exit status
 {
@@ -35,7 +35,8 @@ usage() # $1 = exit status
 }
 
 split() {
-    local ifs=$IFS
+    local ifs
+    ifs=$IFS
     IFS=:
     set -- $1
     echo $*
@@ -148,13 +149,25 @@ if [ -z "$RUNLEVELS" ] ; then
 	RUNLEVELS=""
 fi
 
-if [ -z "$OWNER" ] ; then
-	OWNER=root
-fi
+DEBIAN=
+CYGWIN=
+MANDIR=${MANDIR:-"/usr/share/man"}
 
-if [ -z "$GROUP" ] ; then
-	GROUP=root
-fi
+case $(uname) in
+    CYGWIN*)
+	DEST=
+	INIT=
+	OWNER=$(id -un)
+	GROUP=$(id -gn)
+	CYGWIN=Yes
+	;;
+    *)
+	[ -z "$OWNER" ] && OWNER=root
+	[ -z "$GROUP" ] && GROUP=root
+	;;
+esac
+
+OWNERSHIP="-o $OWNER -g $GROUP"
 
 NOBACKUP=
 
@@ -183,11 +196,9 @@ PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/bin:/usr/local/sbin
 #
 # Determine where to install the firewall script
 #
-DEBIAN=
-
-OWNERSHIP="-o $OWNER -g $GROUP"
 
 if [ -n "$PREFIX" ]; then
+    if [ -z "$CYGWIN" ]; then
 	if [ `id -u` != 0 ] ; then
 	    echo "Not setting file owner/group permissions, not running as root."
 	    OWNERSHIP=""
@@ -195,18 +206,23 @@ if [ -n "$PREFIX" ]; then
 
 	install -d $OWNERSHIP -m 755 ${PREFIX}/sbin
 	install -d $OWNERSHIP -m 755 ${PREFIX}${DEST}
+    fi
 else
     [ -x /usr/share/shorewall-shell/compiler -o -x /usr/share/shorewall-perl/compiler.pl ] || \
 	{ echo "   ERROR: No Shorewall compiler is installed" >&2; exit 1; }
-    if [ -d /etc/apt -a -e /usr/bin/dpkg ]; then
-	DEBIAN=yes
-    elif [ -f /etc/slackware-version ] ; then
-	DEST="/etc/rc.d"
-	INIT="rc.firewall"
-    elif [ -f /etc/arch-release ] ; then
-	DEST="/etc/rc.d"
-	INIT="shorewall"
-	ARCHLINUX=yes
+    if [ -z "$CYGWIN" ]; then
+	if [ -d /etc/apt -a -e /usr/bin/dpkg ]; then
+	    DEBIAN=yes
+	elif [ -f /etc/slackware-version ] ; then
+	    echo "installing Slackware specific configuration..."
+	    DEST="/etc/rc.d"
+	    MANDIR="/usr/man"
+	    SLACKWARE=yes
+	elif [ -f /etc/arch-release ] ; then
+	    DEST="/etc/rc.d"
+	    INIT="shorewall"
+	    ARCHLINUX=yes
+	fi
     fi
 fi
 
@@ -231,9 +247,14 @@ else
     first_install="Yes"
 fi
 
-install_file_with_backup shorewall ${PREFIX}/sbin/shorewall 0755 ${PREFIX}/var/lib/shorewall-${VERSION}.bkout
+if [ -z "$CYGWIN" ]; then
+   install_file_with_backup shorewall ${PREFIX}/sbin/shorewall 0755 ${PREFIX}/var/lib/shorewall-${VERSION}.bkout
+   echo "shorewall control program installed in ${PREFIX}/sbin/shorewall"
+else
+   install_file_with_backup shorewall ${PREFIX}/bin/shorewall 0755 ${PREFIX}/var/lib/shorewall-${VERSION}.bkout
+   echo "shorewall control program installed in ${PREFIX}/bin/shorewall"
+fi
 
-echo "shorewall control program installed in ${PREFIX}/sbin/shorewall"
 
 #
 # Install the Firewall Script
@@ -242,12 +263,14 @@ if [ -n "$DEBIAN" ]; then
     install_file_with_backup init.debian.sh /etc/init.d/shorewall 0544 ${PREFIX}/usr/share/shorewall-${VERSION}.bkout
 elif [ -n "$ARCHLINUX" ]; then
     install_file_with_backup init.archlinux.sh ${PREFIX}${DEST}/$INIT 0544 ${PREFIX}/usr/share/shorewall-${VERSION}.bkout
-
-else
+elif [ -n "$SLACKWARE" ]; then
+	install_file_with_backup init.slackware.firewall.sh ${PREFIX}${DEST}/rc.firewall 0644 ${PREFIX}/usr/share/shorewall-${VERSION}.bkout
+	install_file_with_backup init.slackware.shorewall.sh ${PREFIX}${DEST}/rc.shorewall 0644 ${PREFIX}/usr/share/shorewall-${VERSION}.bkout
+elif [ -n "$INIT" ]; then
     install_file_with_backup init.sh ${PREFIX}${DEST}/$INIT 0544 ${PREFIX}/usr/share/shorewall-${VERSION}.bkout
 fi
 
-echo  "Shorewall script installed in ${PREFIX}${DEST}/$INIT"
+[ -n "$CYGWIN" ] || echo  "Shorewall script installed in ${PREFIX}${DEST}/$INIT"
 
 #
 # Create /etc/shorewall, /usr/share/shorewall and /var/shorewall if needed
@@ -281,7 +304,7 @@ fi
 #
 run_install $OWNERSHIP -m 0644 zones ${PREFIX}/usr/share/shorewall/configfiles/zones
 
-if [ ! -f ${PREFIX}/etc/shorewall/zones ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/zones ]; then
     run_install $OWNERSHIP -m 0744 zones ${PREFIX}/etc/shorewall/zones
     echo "Zones file installed as ${PREFIX}/etc/shorewall/zones"
 fi
@@ -314,7 +337,7 @@ echo "wait4ifup installed in ${PREFIX}/usr/share/shorewall/wait4ifup"
 #
 run_install $OWNERSHIP -m 0644 policy ${PREFIX}/usr/share/shorewall/configfiles/policy
 
-if [ ! -f ${PREFIX}/etc/shorewall/policy ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/policy ]; then
     run_install $OWNERSHIP -m 0600 policy ${PREFIX}/etc/shorewall/policy
     echo "Policy file installed as ${PREFIX}/etc/shorewall/policy"
 fi
@@ -323,7 +346,7 @@ fi
 #
 run_install $OWNERSHIP -m 0644 interfaces ${PREFIX}/usr/share/shorewall/configfiles/interfaces
 
-if [ ! -f ${PREFIX}/etc/shorewall/interfaces ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/interfaces ]; then
     run_install $OWNERSHIP -m 0600 interfaces ${PREFIX}/etc/shorewall/interfaces
     echo "Interfaces file installed as ${PREFIX}/etc/shorewall/interfaces"
 fi
@@ -332,7 +355,7 @@ fi
 #
 run_install $OWNERSHIP -m 0644 ipsec ${PREFIX}/usr/share/shorewall/configfiles/ipsec
 
-if [ ! -f ${PREFIX}/etc/shorewall/ipsec ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/ipsec ]; then
     run_install $OWNERSHIP -m 0600 ipsec ${PREFIX}/etc/shorewall/ipsec
     echo "Dummy IPSEC file installed as ${PREFIX}/etc/shorewall/ipsec"
 fi
@@ -342,7 +365,7 @@ fi
 #
 run_install $OWNERSHIP -m 0644 hosts ${PREFIX}/usr/share/shorewall/configfiles/hosts
 
-if [ ! -f ${PREFIX}/etc/shorewall/hosts ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/hosts ]; then
     run_install $OWNERSHIP -m 0600 hosts ${PREFIX}/etc/shorewall/hosts
     echo "Hosts file installed as ${PREFIX}/etc/shorewall/hosts"
 fi
@@ -351,7 +374,7 @@ fi
 #
 run_install $OWNERSHIP -m 0644 rules ${PREFIX}/usr/share/shorewall/configfiles/rules
 
-if [ ! -f ${PREFIX}/etc/shorewall/rules ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/rules ]; then
     run_install $OWNERSHIP -m 0600 rules ${PREFIX}/etc/shorewall/rules
     echo "Rules file installed as ${PREFIX}/etc/shorewall/rules"
 fi
@@ -360,7 +383,7 @@ fi
 #
 run_install $OWNERSHIP -m 0644 nat ${PREFIX}/usr/share/shorewall/configfiles/nat
 
-if [ ! -f ${PREFIX}/etc/shorewall/nat ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/nat ]; then
     run_install $OWNERSHIP -m 0600 nat ${PREFIX}/etc/shorewall/nat
     echo "NAT file installed as ${PREFIX}/etc/shorewall/nat"
 fi
@@ -369,7 +392,7 @@ fi
 #
 run_install $OWNERSHIP -m 0644 netmap ${PREFIX}/usr/share/shorewall/configfiles/netmap
 
-if [ ! -f ${PREFIX}/etc/shorewall/netmap ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/netmap ]; then
     run_install $OWNERSHIP -m 0600 netmap ${PREFIX}/etc/shorewall/netmap
     echo "NETMAP file installed as ${PREFIX}/etc/shorewall/netmap"
 fi
@@ -389,7 +412,7 @@ fi
 #
 run_install $OWNERSHIP -m 0644 proxyarp ${PREFIX}/usr/share/shorewall/configfiles/proxyarp
 
-if [ ! -f ${PREFIX}/etc/shorewall/proxyarp ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/proxyarp ]; then
     run_install $OWNERSHIP -m 0600 proxyarp ${PREFIX}/etc/shorewall/proxyarp
     echo "Proxy ARP file installed as ${PREFIX}/etc/shorewall/proxyarp"
 fi
@@ -398,7 +421,7 @@ fi
 #
 run_install $OWNERSHIP -m 0644 routestopped ${PREFIX}/usr/share/shorewall/configfiles/routestopped
 
-if [ ! -f ${PREFIX}/etc/shorewall/routestopped ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/routestopped ]; then
     run_install $OWNERSHIP -m 0600 routestopped ${PREFIX}/etc/shorewall/routestopped
     echo "Stopped Routing file installed as ${PREFIX}/etc/shorewall/routestopped"
 fi
@@ -407,7 +430,7 @@ fi
 #
 run_install $OWNERSHIP -m 0644 maclist ${PREFIX}/usr/share/shorewall/configfiles/maclist
 
-if [ ! -f ${PREFIX}/etc/shorewall/maclist ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/maclist ]; then
     run_install $OWNERSHIP -m 0600 maclist ${PREFIX}/etc/shorewall/maclist
     echo "MAC list file installed as ${PREFIX}/etc/shorewall/maclist"
 fi
@@ -416,11 +439,20 @@ fi
 #
 run_install $OWNERSHIP -m 0644 masq ${PREFIX}/usr/share/shorewall/configfiles/masq
 
-if [ ! -f ${PREFIX}/etc/shorewall/masq ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/masq ]; then
     run_install $OWNERSHIP -m 0600 masq ${PREFIX}/etc/shorewall/masq
     echo "Masquerade file installed as ${PREFIX}/etc/shorewall/masq"
 fi
 #
+# Install the Notrack file
+#
+run_install $OWNERSHIP -m 0644 notrack ${PREFIX}/usr/share/shorewall/configfiles/notrack
+
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/notrack ]; then
+    run_install $OWNERSHIP -m 0600 notrack ${PREFIX}/etc/shorewall/notrack
+    echo "Notrack file installed as ${PREFIX}/etc/shorewall/notrack"
+fi
+#
 # Install the Modules file
 #
 run_install $OWNERSHIP -m 0600 modules ${PREFIX}/usr/share/shorewall/modules
@@ -431,7 +463,7 @@ echo "Modules file installed as ${PREFIX}/usr/share/shorewall/modules"
 #
 run_install $OWNERSHIP -m 0644 tcrules ${PREFIX}/usr/share/shorewall/configfiles/tcrules
 
-if [ ! -f ${PREFIX}/etc/shorewall/tcrules ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/tcrules ]; then
     run_install $OWNERSHIP -m 0600 tcrules ${PREFIX}/etc/shorewall/tcrules
     echo "TC Rules file installed as ${PREFIX}/etc/shorewall/tcrules"
 fi
@@ -441,7 +473,7 @@ fi
 #
 run_install $OWNERSHIP -m 0644 tos ${PREFIX}/usr/share/shorewall/configfiles/tos
 
-if [ ! -f ${PREFIX}/etc/shorewall/tos ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/tos ]; then
     run_install $OWNERSHIP -m 0600 tos ${PREFIX}/etc/shorewall/tos
     echo "TOS file installed as ${PREFIX}/etc/shorewall/tos"
 fi
@@ -450,7 +482,7 @@ fi
 #
 run_install $OWNERSHIP -m 0644 tunnels ${PREFIX}/usr/share/shorewall/configfiles/tunnels
 
-if [ ! -f ${PREFIX}/etc/shorewall/tunnels ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/tunnels ]; then
     run_install $OWNERSHIP -m 0600 tunnels ${PREFIX}/etc/shorewall/tunnels
     echo "Tunnels file installed as ${PREFIX}/etc/shorewall/tunnels"
 fi
@@ -459,7 +491,7 @@ fi
 #
 run_install $OWNERSHIP -m 0644 blacklist ${PREFIX}/usr/share/shorewall/configfiles/blacklist
 
-if [ ! -f ${PREFIX}/etc/shorewall/blacklist ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/blacklist ]; then
     run_install $OWNERSHIP -m 0600 blacklist ${PREFIX}/etc/shorewall/blacklist
     echo "Blacklist file installed as ${PREFIX}/etc/shorewall/blacklist"
 fi
@@ -487,7 +519,7 @@ delete_file ${PREFIX}/usr/share/shorewall/xmodules
 #
 run_install $OWNERSHIP -m 0644 providers ${PREFIX}/usr/share/shorewall/configfiles/providers
 
-if [ ! -f ${PREFIX}/etc/shorewall/providers ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/providers ]; then
     run_install $OWNERSHIP -m 0600 providers ${PREFIX}/etc/shorewall/providers
     echo "Providers file installed as ${PREFIX}/etc/shorewall/providers"
 fi
@@ -497,7 +529,7 @@ fi
 #
 run_install $OWNERSHIP -m 0644 route_rules ${PREFIX}/usr/share/shorewall/configfiles/route_rules
 
-if [ ! -f ${PREFIX}/etc/shorewall/route_rules ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/route_rules ]; then
     run_install $OWNERSHIP -m 0600 route_rules ${PREFIX}/etc/shorewall/route_rules
     echo "Routing rules file installed as ${PREFIX}/etc/shorewall/route_rules"
 fi
@@ -507,7 +539,7 @@ fi
 #
 run_install $OWNERSHIP -m 0644 tcclasses ${PREFIX}/usr/share/shorewall/configfiles/tcclasses
 
-if [ ! -f ${PREFIX}/etc/shorewall/tcclasses ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/tcclasses ]; then
     run_install $OWNERSHIP -m 0600 tcclasses ${PREFIX}/etc/shorewall/tcclasses
     echo "TC Classes file installed as ${PREFIX}/etc/shorewall/tcclasses"
 fi
@@ -517,11 +549,21 @@ fi
 #
 run_install $OWNERSHIP -m 0644 tcdevices ${PREFIX}/usr/share/shorewall/configfiles/tcdevices
 
-if [ ! -f ${PREFIX}/etc/shorewall/tcdevices ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/tcdevices ]; then
     run_install $OWNERSHIP -m 0600 tcdevices ${PREFIX}/etc/shorewall/tcdevices
     echo "TC Devices file installed as ${PREFIX}/etc/shorewall/tcdevices"
 fi
 
+#
+# Install the tcfilters file
+#
+run_install $OWNERSHIP -m 0644 tcfilters ${PREFIX}/usr/share/shorewall/configfiles/tcfilters
+
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/tcfilters ]; then
+    run_install $OWNERSHIP -m 0600 tcfilters ${PREFIX}/etc/shorewall/tcfilters
+    echo "TC Filters file installed as ${PREFIX}/etc/shorewall/tcfilters"
+fi
+
 #
 # Install the rfc1918 file
 #
@@ -537,7 +579,7 @@ echo "Default config path file installed as ${PREFIX}/usr/share/shorewall/config
 #
 run_install $OWNERSHIP -m 0644 init ${PREFIX}/usr/share/shorewall/configfiles/init
 
-if [ ! -f ${PREFIX}/etc/shorewall/init ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/init ]; then
     run_install $OWNERSHIP -m 0600 init ${PREFIX}/etc/shorewall/init
     echo "Init file installed as ${PREFIX}/etc/shorewall/init"
 fi
@@ -546,7 +588,7 @@ fi
 #
 run_install $OWNERSHIP -m 0644 initdone ${PREFIX}/usr/share/shorewall/configfiles/initdone
 
-if [ ! -f ${PREFIX}/etc/shorewall/initdone ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/initdone ]; then
     run_install $OWNERSHIP -m 0600 initdone ${PREFIX}/etc/shorewall/initdone
     echo "Initdone file installed as ${PREFIX}/etc/shorewall/initdone"
 fi
@@ -555,7 +597,7 @@ fi
 #
 run_install $OWNERSHIP -m 0644 start ${PREFIX}/usr/share/shorewall/configfiles/start
 
-if [ ! -f ${PREFIX}/etc/shorewall/start ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/start ]; then
     run_install $OWNERSHIP -m 0600 start ${PREFIX}/etc/shorewall/start
     echo "Start file installed as ${PREFIX}/etc/shorewall/start"
 fi
@@ -564,7 +606,7 @@ fi
 #
 run_install $OWNERSHIP -m 0644 stop ${PREFIX}/usr/share/shorewall/configfiles/stop
 
-if [ ! -f ${PREFIX}/etc/shorewall/stop ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/stop ]; then
     run_install $OWNERSHIP -m 0600 stop ${PREFIX}/etc/shorewall/stop
     echo "Stop file installed as ${PREFIX}/etc/shorewall/stop"
 fi
@@ -573,7 +615,7 @@ fi
 #
 run_install $OWNERSHIP -m 0644 stopped ${PREFIX}/usr/share/shorewall/configfiles/stopped
 
-if [ ! -f ${PREFIX}/etc/shorewall/stopped ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/stopped ]; then
     run_install $OWNERSHIP -m 0600 stopped ${PREFIX}/etc/shorewall/stopped
     echo "Stopped file installed as ${PREFIX}/etc/shorewall/stopped"
 fi
@@ -582,7 +624,7 @@ fi
 #
 run_install $OWNERSHIP -m 0644 ecn ${PREFIX}/usr/share/shorewall/configfiles/ecn
 
-if [ ! -f ${PREFIX}/etc/shorewall/ecn ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/ecn ]; then
     run_install $OWNERSHIP -m 0600 ecn ${PREFIX}/etc/shorewall/ecn
     echo "ECN file installed as ${PREFIX}/etc/shorewall/ecn"
 fi
@@ -591,7 +633,7 @@ fi
 #
 run_install $OWNERSHIP -m 0644 accounting ${PREFIX}/usr/share/shorewall/configfiles/accounting
 
-if [ ! -f ${PREFIX}/etc/shorewall/accounting ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/accounting ]; then
     run_install $OWNERSHIP -m 0600 accounting ${PREFIX}/etc/shorewall/accounting
     echo "Accounting file installed as ${PREFIX}/etc/shorewall/accounting"
 fi
@@ -600,7 +642,7 @@ fi
 #
 run_install $OWNERSHIP -m 0644 continue ${PREFIX}/usr/share/shorewall/configfiles/continue
 
-if [ ! -f ${PREFIX}/etc/shorewall/continue ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/continue ]; then
     run_install $OWNERSHIP -m 0600 continue ${PREFIX}/etc/shorewall/continue
     echo "Continue file installed as ${PREFIX}/etc/shorewall/continue"
 fi
@@ -609,22 +651,31 @@ fi
 #
 run_install $OWNERSHIP -m 0644 started ${PREFIX}/usr/share/shorewall/configfiles/started
 
-if [ ! -f ${PREFIX}/etc/shorewall/started ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/started ]; then
     run_install $OWNERSHIP -m 0600 started ${PREFIX}/etc/shorewall/started
     echo "Started file installed as ${PREFIX}/etc/shorewall/started"
 fi
 #
+# Install the Restored file
+#
+run_install $OWNERSHIP -m 0644 restored ${PREFIX}/usr/share/shorewall/configfiles/restored
+
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/restored ]; then
+    run_install $OWNERSHIP -m 0600 restored ${PREFIX}/etc/shorewall/restored
+    echo "Restored file installed as ${PREFIX}/etc/shorewall/restored"
+fi
+#
 # Install the Standard Actions file
 #
 install_file actions.std ${PREFIX}/usr/share/shorewall/actions.std 0644
-echo "Standard actions file installed as ${PREFIX}/etc/shorewall/actions.std"
+echo "Standard actions file installed as ${PREFIX}/usr/shared/shorewall/actions.std"
 
 #
 # Install the Actions file
 #
 run_install $OWNERSHIP -m 0644 actions ${PREFIX}/usr/share/shorewall/configfiles/actions
 
-if [ ! -f ${PREFIX}/etc/shorewall/actions ]; then
+if [ -z "$CYGWIN" -a ! -f ${PREFIX}/etc/shorewall/actions ]; then
     run_install $OWNERSHIP -m 0644 actions ${PREFIX}/etc/shorewall/actions
     echo "Actions file installed as ${PREFIX}/etc/shorewall/actions"
 fi
@@ -633,9 +684,11 @@ fi
 # Install the  Makefiles
 #
 run_install $OWNERSHIP -m 0644 Makefile-lite ${PREFIX}/usr/share/shorewall/configfiles/Makefile
-run_install $OWNERSHIP -m 0600 Makefile ${PREFIX}/etc/shorewall/Makefile
-echo "Makefile installed as ${PREFIX}/etc/shorewall/Makefile"
 
+if [ -z "$CYGWIN" ]; then
+    run_install $OWNERSHIP -m 0600 Makefile ${PREFIX}/etc/shorewall/Makefile
+    echo "Makefile installed as ${PREFIX}/etc/shorewall/Makefile"
+fi
 #
 # Install the Action files
 #
@@ -685,14 +738,14 @@ cd manpages
 
 for f in *.5; do
     gzip -c $f > $f.gz
-    run_install -D  -m 0644 $f.gz ${PREFIX}/usr/share/man/man5/$f.gz
-    echo "Man page $f.gz installed to /usr/share/man/man5/$f.gz"
+    run_install -D  -m 0644 $f.gz ${PREFIX}${MANDIR}/man5/$f.gz
+    echo "Man page $f.gz installed to ${PREFIX}${MANDIR}/man5/$f.gz"
 done
 
 for f in *.8; do
     gzip -c $f > $f.gz
-    run_install -D  -m 0644 $f.gz ${PREFIX}/usr/share/man/man8/$f.gz
-    echo "Man page $f.gz installed to /usr/share/man/man8/$f.gz"
+    run_install -D  -m 0644 $f.gz ${PREFIX}${MANDIR}/man8/$f.gz
+    echo "Man page $f.gz installed to ${PREFIX}${MANDIR}/man8/$f.gz"
 done
 
 cd ..
@@ -704,7 +757,7 @@ echo "Man Pages Installed"
 #
 install_file firewall ${PREFIX}/usr/share/shorewall/firewall 0755
 
-if [ -z "$PREFIX" -a -n "$first_install" ]; then
+if [ -z "$PREFIX" -a -n "$first_install" -a -z "$CYGWIN" ]; then
     if [ -n "$DEBIAN" ]; then
 	run_install $OWNERSHIP -m 0644 default.debian /etc/default/shorewall
 	ln -s ../init.d/shorewall /etc/rcS.d/S40shorewall
